@@ -57,18 +57,23 @@ def standardize(tensor, axis=0, return_mean=False):
 
 
 
-def load_weights(model, git_link , model_name, overwrite=False):
+def load_weights(model, git_link , model_name, overwrite=True):
     
     # Creating a temporary directory and getting the saved weights
     model_path = os.path.join(os.getcwd(), model_name)
-    test_dir = tempfile.mkdtemp()
-    git.Repo.clone_from(git_link, test_dir, branch='main', depth=1)
-    if os.path.exists(model_path):
-        if overwrite:
-            os.remove(model_path)
-        else:
-            print("The saved weights already exists")
-    shutil.move(os.path.join(test_dir, model_name), os.getcwd())
+    
+    try: 
+        test_dir = tempfile.mkdtemp()
+        git.Repo.clone_from(git_link, test_dir, branch='main', depth=1)
+        if os.path.exists(model_path):
+            if overwrite:
+                shutil.rmtree(model_path)
+            else:
+                print("The saved weights already exists")
+    except:
+        print("Couldn't load the model")
+    finally:
+        shutil.move(os.path.join(test_dir, model_name), os.getcwd())
     # shutil.rmtree(test_dir)
 
     # Loading the model
